Developers
----------

* Mika Pflüger `<mika.pflueger@pik-potsdam.de>`_

Contributors
------------

* Florian Dierickx `<floriandierickx.github.io>`_
* Daniel Huppmann `<https://twitter.com/daniel_huppmann>`_
* Johannes Gütschow <johannes.guetschow@pik-potsdam.de>
